﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.IO;

namespace Test
{
    public partial class frmSample : Form
    {
        public frmSample()
        {
            new SorrenUSBCID.USBCallerID().AboutUs();
            InitializeComponent();
            txtInfo.Text = usbCallerID1.GetInfo();
            if (usbCallerID1.IsConnected)
            {
                txtStatus.Text = "Connected";
            }
            else
            {
                txtStatus.Text = "Disconnected";
            }
        }
        private void frmTest_Load(object sender, EventArgs e)
        {
            dgvData.Rows.Add(10);
            for (int i = 0; i < 10; i++)
                dgvData.Rows[i].Cells["Line"].Value = i + 1;
            usbCallerID1.AreaCode = "021";
            usbCallerID1.Lines = 10;

            if (usbCallerID1.IsConnected)
                btnOpen_Click(new object(), new EventArgs());
        }
        private void frmTest_FormClosing(object sender, FormClosingEventArgs e)
        {
            btnClose_Click(new object(), new EventArgs());
        }

        private void usbCallerID1_NewCID(SorrenUSBCID.USBCallerID.Sorren_USB_CallerID_EventArgs e)
        {
            dgvData["Type", e.Line - 1].Value = e.Type;
            dgvData["Tel", e.Line - 1].Value = e.PhoneID;
            dgvData["Time", e.Line - 1].Value = e.Date + " " + e.Time;
            string log = "New Data Received ";
            log += "\r\nLog:" + e.Log;
            AddLog(log);
        }
        private void usbCallerID1_StatusChanged(SorrenUSBCID.USBCallerID.Sorren_USB_CallerID_Status e)
        {
            switch (e.State)
            {
                case SorrenUSBCID.USBCallerID.Status.DeviceConnected:
                    txtStatus.Text = "Connected";
                    AddLog("Device Connected");
                    btnOpen_Click(new object(), new EventArgs());
                    break;
                case SorrenUSBCID.USBCallerID.Status.DeviceDisconnected:
                    txtStatus.Text = "Disconnected";
                    AddLog("Device Disconnected");
                    btnClose_Click(new object(), new EventArgs());
                    break;
            }
            txtInfo.Text = usbCallerID1.GetInfo();
        }
        private void btnOpen_Click(object sender, EventArgs e)
        {
            if (usbCallerID1.OpenDevice())
            {
                btnOpen.Enabled = false;
                btnClose.Enabled = true;
                chkFilter.Enabled = true;
                AddLog("Device Opened");
            }
        }
        private void btnClose_Click(object sender, EventArgs e)
        {
            if (usbCallerID1.CloseDevice())
            {
                btnClose.Enabled = false;
                btnOpen.Enabled = true;
                chkFilter.Enabled = false;
                AddLog("Device Closed");
            }
        }
        private void btnClearLog_Click(object sender, EventArgs e)
        {
            txtLog.Text = "";
        }
        private void btnSave_Click(object sender, EventArgs e)
        {
            sfdSave.ShowDialog();
            string fn = sfdSave.FileName;
            if (fn == null || fn == "")
                return;
            txtLog.SaveFile(sfdSave.FileName,RichTextBoxStreamType.UnicodePlainText);
        }
        private void btnClearList_Click(object sender, EventArgs e)
        {
            foreach (DataGridViewRow dgvr in dgvData.Rows)
            {
                dgvr.Cells["Type"].Value = "";
                dgvr.Cells["Tel"].Value = "";
                dgvr.Cells["Time"].Value = "";
            }
        }
        private void btnAbout_Click(object sender, EventArgs e)
        {
            //usbCallerID1.AboutUs();
        }
        private void chkFilter_CheckedChanged(object sender, EventArgs e)
        {
            usbCallerID1.AutoFilter = chkFilter.Checked;
        }

        private void AddLog(string log)
        {
            txtLog.Text += log;
            txtLog.Text += "\r\n\r\n";
            txtLog.SelectionStart = txtLog.Text.Length;
            txtLog.SelectionLength = 0;
            txtLog.ScrollToCaret();
        }
        private void dgvData_CellClick(object sender, DataGridViewCellEventArgs e)
        {
            if (e.RowIndex < 0)
                return;
            dgvData["Type", e.RowIndex].Value = "";
            dgvData["Tel", e.RowIndex].Value = "";
            dgvData["Time", e.RowIndex].Value = "";
        }
    }
}
